@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use Carp;
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 use Exporter 'import';
 our @EXPORT_OK = qw(&ansi_printf &ansi_sprintf);
@@ -16,6 +16,7 @@ use Text::VisualPrintf;
 use Text::ANSI::Fold::Util;
 
 sub sprintf {
+    local $Text::VisualPrintf::IS_TARGET = qr/[\e\b\P{ASCII}]/;
     local $Text::VisualPrintf::VISUAL_WIDTH = \&Text::ANSI::Fold::Util::width;
     Text::VisualPrintf::sprintf(@_);
 }
@@ -37,7 +38,7 @@ Text::ANSI::Printf - printf function for string with ANSI sequence
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =head1 SYNOPSIS
 
@@ -51,9 +52,12 @@ Version 1.02
 
 =head1 DESCRIPTION
 
-Text::ANSI::Printf is a almost-printf-compatible library with a
-capability of handling string with ANSI color sequences, as well as
-multi-byte wide characters.
+B<Text::ANSI::Printf> is a almost-printf-compatible library with a
+capability of handling:
+
+    - ANSI terminal sequences
+    - Multi-byte wide characters
+    - Backspaces
 
 =head1 FUNCTIONS
 
